@@ -10,7 +10,10 @@ class FbConstants:
         'status',
         'quality_rating',
         'id',
-        'display_phone_number'
+        'display_phone_number',
+        'thread_limit_per_day'
     ]
 
     PHONE_NUMBERS_EDGE = 'phone_numbers'
+
+    MESSAGE_TEMPLATES_EDGE = 'message_templates'
